run_from

Function run_from 

pub fn run_from<I, T>(args: I) -> Result<i32>
where I: IntoIterator<Item = T>, T: Into<OsString> + Clone,
Runs the top-level CLI entrypoint from an argv-like iterator.

This is the library-friendly wrapper around the binary entrypoint and returns the process exit code that should be reported to the caller.