run_process

Function run_process 

pub fn run_process<I, T>(args: I) -> i32
where I: IntoIterator<Item = T>, T: Into<OsString> + Clone,
Runs the default application instance and returns a process exit code.

This is shorthand for building App::new and calling App::run_process, using process stdio for rendered output and user-facing errors.

Examples

let exit = osp_cli::app::run_process(["osp", "--help"]);

assert_eq!(exit, 0);