pub struct AuthState { /* private fields */ }Expand description
Authorization and command-visibility state derived from configuration.
Implementations
Sourceimpl AuthState
impl AuthState
Sourcepub fn from_resolved(config: &ResolvedConfig) -> Self
pub fn from_resolved(config: &ResolvedConfig) -> Self
Builds authorization state from the resolved configuration.
Sourcepub fn policy_context(&self) -> &CommandPolicyContext
pub fn policy_context(&self) -> &CommandPolicyContext
Returns the context used when evaluating command policies.
Sourcepub fn set_policy_context(&mut self, context: CommandPolicyContext)
pub fn set_policy_context(&mut self, context: CommandPolicyContext)
Replaces the context used when evaluating command policies.
Sourcepub fn builtin_policy(&self) -> &CommandPolicyRegistry
pub fn builtin_policy(&self) -> &CommandPolicyRegistry
Returns the policy registry for built-in commands.
Sourcepub fn builtin_policy_mut(&mut self) -> &mut CommandPolicyRegistry
pub fn builtin_policy_mut(&mut self) -> &mut CommandPolicyRegistry
Returns the mutable policy registry for built-in commands.
Sourcepub fn external_policy(&self) -> &CommandPolicyRegistry
pub fn external_policy(&self) -> &CommandPolicyRegistry
Returns the policy registry for externally dispatched commands.
Sourcepub fn external_policy_mut(&mut self) -> &mut CommandPolicyRegistry
pub fn external_policy_mut(&mut self) -> &mut CommandPolicyRegistry
Returns the mutable policy registry for externally dispatched commands.
Sourcepub fn replace_external_policy(&mut self, registry: CommandPolicyRegistry)
pub fn replace_external_policy(&mut self, registry: CommandPolicyRegistry)
Replaces the policy registry for externally dispatched commands.
Sourcepub fn builtin_access(&self, command: &str) -> CommandAccess
pub fn builtin_access(&self, command: &str) -> CommandAccess
Evaluates access for a built-in command.
Sourcepub fn external_command_access(&self, command: &str) -> CommandAccess
pub fn external_command_access(&self, command: &str) -> CommandAccess
Evaluates access for an external command.
Sourcepub fn is_builtin_visible(&self, command: &str) -> bool
pub fn is_builtin_visible(&self, command: &str) -> bool
Returns whether a built-in command should be shown to the user.
Sourcepub fn is_external_command_visible(&self, command: &str) -> bool
pub fn is_external_command_visible(&self, command: &str) -> bool
Returns whether an external command should be shown to the user.