Module tree

Module tree 

Declarative completion-tree builders derived from command and config metadata. Declarative builders for the completion engine’s immutable tree model.

Public API shape:

Structs

CommandSpec
Declarative command description used to build a completion tree.
CompletionTreeBuilder
Builds immutable completion trees from command and config metadata.
ConfigKeySpec
Declarative config set key metadata used for completion nodes.

Enums

CompletionTreeBuildError
Error returned when declarative completion metadata cannot be lowered into a valid immutable tree.