ConfigLoader

Trait ConfigLoader 

pub trait ConfigLoader: Send + Sync {
    // Required method
    fn load(&self) -> Result<ConfigLayer, ConfigError>;
}
Loads a single config layer from some backing source.

Required Methods

fn load(&self) -> Result<ConfigLayer, ConfigError>

Reads the source and returns it as a config layer.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors