pub enum UiVerbosity {
Error,
Warning,
Success,
Info,
Trace,
}Expand description
UI message verbosity derived from runtime hints and environment.
Variants
Error
Show only errors.
Warning
Show errors and warnings.
Success
Show success messages in addition to warnings and errors.
Info
Show normal informational output.
Trace
Show trace-level output.
Implementations
Sourceimpl UiVerbosity
impl UiVerbosity
Sourcepub fn as_str(self) -> &'static str
pub fn as_str(self) -> &'static str
Returns the canonical string representation for this verbosity level.
Sourcepub fn parse(value: &str) -> Option<Self>
pub fn parse(value: &str) -> Option<Self>
Parses a case-insensitive verbosity level or supported alias.
Examples
use osp_cli::core::runtime::UiVerbosity;
assert_eq!(UiVerbosity::parse("warn"), Some(UiVerbosity::Warning));
assert_eq!(UiVerbosity::parse("TRACE"), Some(UiVerbosity::Trace));
assert_eq!(UiVerbosity::parse("loud"), None);Trait Implementations
Sourceimpl Clone for UiVerbosity
impl Clone for UiVerbosity
Sourcefn clone(&self) -> UiVerbosity
fn clone(&self) -> UiVerbosity
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UiVerbosity
impl Debug for UiVerbosity
Sourceimpl Default for UiVerbosity
impl Default for UiVerbosity
Sourcefn default() -> UiVerbosity
fn default() -> UiVerbosity
Returns the “default value” for a type. Read more
Sourceimpl Ord for UiVerbosity
impl Ord for UiVerbosity
Sourcefn cmp(&self, other: &UiVerbosity) -> Ordering
fn cmp(&self, other: &UiVerbosity) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UiVerbosity
impl PartialEq for UiVerbosity
Sourceimpl PartialOrd for UiVerbosity
impl PartialOrd for UiVerbosity
impl Copy for UiVerbosity
impl Eq for UiVerbosity
impl StructuralPartialEq for UiVerbosity