Module shell_words

Module shell_words 

Shell-like tokenization helpers.

Enums

QuoteStyle
Quoting style to use when formatting a shell argument.

Functions

escape_for_shell
Escapes shell-sensitive characters without adding surrounding quotes.
quote_for_shell
Quotes value for shell reuse using the requested quoting style.