pub fn parse_pipeline(line: &str) -> Result<Pipeline, LexerError>Expand description
Split a full command line into its command portion and raw pipe stages.
pub fn parse_pipeline(line: &str) -> Result<Pipeline, LexerError>Split a full command line into its command portion and raw pipe stages.