pub fn render_output(output: &OutputResult, settings: &RenderSettings) -> StringExpand description
Renders a structured output result using the configured output format.
pub fn render_output(output: &OutputResult, settings: &RenderSettings) -> StringRenders a structured output result using the configured output format.