pub fn apply_style_with_theme(
text: &str,
token: StyleToken,
color: bool,
theme: &ThemeDefinition,
) -> StringExpand description
Applies a theme token using an already resolved theme.
pub fn apply_style_with_theme(
text: &str,
token: StyleToken,
color: bool,
theme: &ThemeDefinition,
) -> StringApplies a theme token using an already resolved theme.