pub fn style_spec<'a>(
theme: &'a ThemeDefinition,
overrides: &'a StyleOverrides,
token: StyleToken,
) -> &'a strExpand description
Returns the style specification for a semantic token under the selected theme.
pub fn style_spec<'a>(
theme: &'a ThemeDefinition,
overrides: &'a StyleOverrides,
token: StyleToken,
) -> &'a strReturns the style specification for a semantic token under the selected theme.