pub fn run_from<I, T>(args: I) -> Result<i32>Expand description
Runs the top-level CLI entrypoint from an argv-like iterator.
This is the library-friendly wrapper around the binary entrypoint and returns the process exit code that should be reported to the caller.