ConfigError

Enum ConfigError 

pub enum ConfigError {
Show 24 variants FileRead { path: String, reason: String, }, FileWrite { path: String, reason: String, }, LayerLoad { path: String, source: Box<ConfigError>, }, InsecureSecretsPermissions { path: String, mode: u32, }, TomlParse(String), TomlRootMustBeTable, UnknownTopLevelSection(String), InvalidSection { section: String, expected: String, }, UnsupportedTomlValue { path: String, kind: String, }, InvalidEnvOverride { key: String, reason: String, }, InvalidConfigKey { key: String, reason: String, }, ReadOnlyConfigKey { key: String, reason: String, }, InvalidBootstrapScope { key: String, profile: Option<String>, terminal: Option<String>, }, MissingDefaultProfile, InvalidBootstrapValue { key: String, reason: String, }, UnknownProfile { profile: String, known: Vec<String>, }, InvalidPlaceholderSyntax { key: String, template: String, }, UnresolvedPlaceholder { key: String, placeholder: String, }, PlaceholderCycle { cycle: Vec<String>, }, NonScalarPlaceholder { key: String, placeholder: String, }, UnknownConfigKeys { keys: Vec<String>, }, MissingRequiredKey { key: String, }, InvalidValueType { key: String, expected: SchemaValueType, actual: String, }, InvalidEnumValue { key: String, value: String, allowed: Vec<String>, },
}
Error type returned by config parsing, validation, and resolution code.

Variants



FileRead

Reading a config file from disk failed.

Fields

path: String

Path that could not be read.

reason: String

Lower-level failure description.



FileWrite

Writing a config file to disk failed.

Fields

path: String

Path that could not be written.

reason: String

Lower-level failure description.



LayerLoad

Adds path context while propagating another config error.

Fields

path: String

Path of the layer being loaded.

source: Box<ConfigError>

Underlying config error.



InsecureSecretsPermissions

Secrets file permissions are broader than allowed.

Fields

path: String

Path of the secrets file.

mode: u32

Observed Unix file mode.



TomlParse(String)

TOML parsing failed before semantic validation.



TomlRootMustBeTable

The parsed TOML document root was not a table.



UnknownTopLevelSection(String)

Encountered an unsupported top-level section name.



InvalidSection

A named section had the wrong TOML type.

Fields

section: String

Fully qualified section name.

expected: String

Expected TOML kind for the section.



UnsupportedTomlValue

Encountered a TOML value kind that the config model does not accept.

Fields

path: String

Dotted config path at which the value was found.

kind: String

TOML value kind that was rejected.



InvalidEnvOverride

An OSP__... environment override used invalid syntax or scope.

Fields

key: String

Environment variable name or derived config key.

reason: String

Validation failure description.



InvalidConfigKey

A config key failed syntactic or semantic validation.

Fields

key: String

Key that failed validation.

reason: String

Validation failure description.



ReadOnlyConfigKey

A caller attempted to write a read-only config key.

Fields

key: String

Key that is read-only.

reason: String

Explanation of why the key is immutable.



InvalidBootstrapScope

A bootstrap-only key was used in a disallowed scope.

Fields

key: String

Bootstrap-only key being validated.

profile: Option<String>

Profile selector present on the rejected scope, if any.

terminal: Option<String>

Terminal selector present on the rejected scope, if any.



MissingDefaultProfile

No usable bootstrap profile name could be determined during bootstrap.

This includes both “no default profile exists” and “the selected bootstrap profile normalized to empty”.



InvalidBootstrapValue

A bootstrap-only key failed its value validation rule.

Fields

key: String

Bootstrap-only key being validated.

reason: String

Validation failure description.



UnknownProfile

Resolution requested a profile that is not known.

Fields

profile: String

Requested profile name.

known: Vec<String>

Known profile names at the time of resolution.



InvalidPlaceholderSyntax

Placeholder syntax inside a template string is malformed.

Fields

key: String

Key containing the invalid template.

template: String

Original template string.



UnresolvedPlaceholder

Placeholder expansion referenced an unknown key.

Fields

key: String

Key whose template is being resolved.

placeholder: String

Placeholder that could not be resolved.



PlaceholderCycle

Placeholder expansion formed a dependency cycle.

Fields

cycle: Vec<String>

Ordered key path describing the detected cycle.



NonScalarPlaceholder

Placeholder expansion referenced a non-scalar value.

Fields

key: String

Key whose template is being resolved.

placeholder: String

Placeholder that resolved to a non-scalar value.



UnknownConfigKeys

One or more config keys are unknown to the schema.

Fields

keys: Vec<String>

Unknown canonical keys.



MissingRequiredKey

A required runtime-visible key was missing after resolution.

Fields

key: String

Missing canonical key.



InvalidValueType

A value could not be adapted to the schema’s declared type.

Fields

key: String

Key whose value had the wrong type.

expected: SchemaValueType

Schema type expected for the key.

actual: String

Actual type name observed during adaptation.



InvalidEnumValue

A string value was outside the schema allow-list.

Fields

key: String

Key whose value was rejected.

value: String

Rejected value.

allowed: Vec<String>

Allowed normalized values.