pub trait ConfigLoader: Send + Sync {
// Required method
fn load(&self) -> Result<ConfigLayer, ConfigError>;
}Expand description
Loads a single config layer from some backing source.
Required Methods
Sourcefn load(&self) -> Result<ConfigLayer, ConfigError>
fn load(&self) -> Result<ConfigLayer, ConfigError>
Reads the source and returns it as a config layer.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".