ConfigLoader

Trait ConfigLoader 

pub trait ConfigLoader: Send + Sync {
    // Required method
    fn load(&self) -> Result<ConfigLayer, ConfigError>;
}
Loads a single config layer from some backing source.

Required Methods

fn load(&self) -> Result<ConfigLayer, ConfigError>

Reads the source and returns it as a config layer.

Implementors