Module style

Module style 

Semantic style tokens and explicit style overrides layered over the theme.

Structs

StyleOverrides
Per-token style overrides layered on top of theme-derived defaults.

Enums

StyleToken
Semantic style token used when rendering text fragments.

Functions

apply_style_spec
Applies a raw style specification to a text fragment.
apply_style_with_theme
Applies a theme token using an already resolved theme.
apply_style_with_theme_overrides
Applies a theme token using a resolved theme and explicit overrides.
is_valid_style_spec
Validates that a style specification uses syntax the renderer understands.